Configuration
#############

Grascii provides a user-level configuration file to set the defaults for several
of its tools.

Getting Started
***************

Create a configuration file with the following command::

  $ grascii config --init

Locate the file with::

  $ grascii config --where

Editing the Configuration
*************************

To change the defaults, open the generated configuration file
and make your desired changes. The available options are described
in the default file.
